@@ -27,6 +27,7 @@ from .paginator import (
     ListTablesPaginator,
 )
 from .type_defs import (
+    BatchExecuteStatementOutputTypeDef,
     CancelStatementResponseTypeDef,
     DescribeStatementResponseTypeDef,
     DescribeTableResponseTypeDef,
@@ -58,6 +59,7 @@ class BotocoreClientError(BaseException):
 
 class Exceptions:
     ActiveStatementsExceededException: Type[BotocoreClientError]
+    BatchExecuteStatementException: Type[BotocoreClientError]
     ClientError: Type[BotocoreClientError]
     ExecuteStatementException: Type[BotocoreClientError]
     InternalServerException: Type[BotocoreClientError]
@@ -67,7 +69,7 @@ class Exceptions:
 
 class RedshiftDataAPIServiceClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html)
     """
 
@@ -79,11 +81,30 @@ class RedshiftDataAPIServiceClient(BaseClient):
         RedshiftDataAPIServiceClient exceptions.
         """
 
+    def batch_execute_statement(
+        self,
+        *,
+        ClusterIdentifier: str,
+        Database: str,
+        Sqls: List[str],
+        DbUser: str = None,
+        SecretArn: str = None,
+        StatementName: str = None,
+        WithEvent: bool = None
+    ) -> BatchExecuteStatementOutputTypeDef:
+        """
+        Runs one or more SQL statements, which can be data manipulation language (DML)
+        or data definition language (DDL).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Client.batch_execute_statement)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#batch_execute_statement)
+        """
+
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#can_paginate)
         """
 
@@ -91,7 +112,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         """
         Cancels a running query.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Client.cancel_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Client.cancel_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#cancel_statement)
         """
 
@@ -100,7 +121,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         Describes the details about a specific instance when a query was run by the
         Amazon Redshift Data API.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Client.describe_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Client.describe_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#describe_statement)
         """
 
@@ -120,7 +141,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         """
         Describes the detailed information about a table from metadata in the cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Client.describe_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Client.describe_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#describe_table)
         """
 
@@ -128,8 +149,8 @@ class RedshiftDataAPIServiceClient(BaseClient):
         self,
         *,
         ClusterIdentifier: str,
+        Database: str,
         Sql: str,
-        Database: str = None,
         DbUser: str = None,
         Parameters: List["SqlParameterTypeDef"] = None,
         SecretArn: str = None,
@@ -140,7 +161,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         Runs an SQL statement, which can be data manipulation language (DML) or data
         definition language (DDL).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Client.execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Client.execute_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#execute_statement)
         """
 
@@ -154,7 +175,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#generate_presigned_url)
         """
 
@@ -164,7 +185,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         """
         Fetches the temporarily cached result of an SQL statement.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Client.get_statement_result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Client.get_statement_result)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#get_statement_result)
         """
 
@@ -172,7 +193,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         self,
         *,
         ClusterIdentifier: str,
-        Database: str = None,
+        Database: str,
         DbUser: str = None,
         MaxResults: int = None,
         NextToken: str = None,
@@ -181,7 +202,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         """
         List the databases in a cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_databases)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_databases)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#list_databases)
         """
 
@@ -200,7 +221,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         """
         Lists the schemas in a database.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_schemas)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_schemas)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#list_schemas)
         """
 
@@ -216,7 +237,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         """
         List of SQL statements.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_statements)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_statements)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#list_statements)
         """
 
@@ -236,14 +257,14 @@ class RedshiftDataAPIServiceClient(BaseClient):
         """
         List the tables in a database.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_tables)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_tables)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/client.html#list_tables)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_table"]) -> DescribeTablePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#describetablepaginator)
         """
 
@@ -252,34 +273,34 @@ class RedshiftDataAPIServiceClient(BaseClient):
         self, operation_name: Literal["get_statement_result"]
     ) -> GetStatementResultPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#getstatementresultpaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_databases"]) -> ListDatabasesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listdatabasespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_schemas"]) -> ListSchemasPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listschemaspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_statements"]) -> ListStatementsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#liststatementspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tables"]) -> ListTablesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.7/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.9/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_redshift_data/paginators.html#listtablespaginator)
         """
